dateutil: Extensions to the standard Python module datetime
===========================================================

Description
-----------

The dateutil module provides powerful extensions to the standard
datetime module.

License
-------

Simplified BSD License


Upstream Contact
----------------

Author: Gustavo Niemeyer <gustavo@niemeyer.net>

Home page: http://labix.org/python-dateutil

https://pypi.org/project/python-dateutil/

Dependencies
------------

-  Python
-  Six
